Returns Ok(true) if the path points at an existing entity.
Returns the canonical, absolute form of a path with all intermediate
components normalized and symbolic links resolved.
Copies the contents of one file to another. This function will also
copy the permission bits of the original file to the destination file.
Creates a new, empty directory at the provided path
Recursively create a directory and all of its parent components if they
are missing.
Creates a new hard link on the filesystem.
Given a path, query the file system to get information about a file,
directory, etc.
Read the entire contents of a file into a bytes vector.
Returns an iterator over the entries within a directory.
Reads a symbolic link, returning the file that the link points to.
Removes an empty directory.
Rename a file or directory to a new name, replacing the original file if
to already exists.
Changes the permissions found on a file or a directory.
Creates a new symbolic link on the filesystem.
Create symbolic link at to pointing to from
Create symbolic link at to pointing to from
Query the metadata about a file without following symlinks.
Write a slice as the entire contents of a file.